@@ -84,9 +84,6 @@ unsigned long long hex2dec(char *str);
 /* get highres time as double */
 extern double get_time_as_double(void);
 
-/* get host polling time */
-extern char *get_host_poll_time(void);
-
 /* function to check to see if program has capability to use raw socket with
    out uid = 0 */
 extern int hasCaps();
